@@ -2,10 +2,11 @@ package Alien::Hunspell;
 
 use strict;
 use warnings;
-use parent 'Alien::Base';
+use base 'Alien::Base';
 
 # ABSTRACT: Install hunspell
-our $VERSION = '0.09_02'; # TRIAL VERSION
+our $VERSION = '0.12_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 
@@ -24,7 +25,7 @@ Alien::Hunspell - Install hunspell
 
 =head1 VERSION
 
-version 0.09_02
+version 0.12_01
 
 =head1 SYNOPSIS
 
